==> elasticsearch-river-remote-1.2.4-sources.jar: org/jboss/elasticsearch/river/remote/mgm/fullupdate/NodeFullUpdateResponse.java <==
package org.jboss.elasticsearch.river.remote.mgm.fullupdate;

import java.io.IOException;

import org.elasticsearch.cluster.node.DiscoveryNode;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;
import org.jboss.elasticsearch.river.remote.mgm.NodeJRMgmBaseResponse;

/**
 * Full reindex node response.
 * 
 * @author Vlastimil Elias (velias at redhat dot com)
 */
public class NodeFullUpdateResponse extends NodeJRMgmBaseResponse {

	boolean spaceFound;

	String reindexedSpaces;

	protected NodeFullUpdateResponse() {
	}

	public NodeFullUpdateResponse(DiscoveryNode node) {
		super(node);
	}

	/**
	 * Create response with values to be send back to requestor.
	 * 
	 * @param node this response is for.
	 * @param riverFound set to true if you found river on this node
	 * @param spaceFound set to true if space reindex was requested and we found this space in given river
	 * @param reindexedSpaces CSV names of Spaces which was forced for full reindex
	 */
	public NodeFullUpdateResponse(DiscoveryNode node, boolean riverFound, boolean spaceFound, String reindexedSpaces) {
		super(node, riverFound);
		this.spaceFound = spaceFound;
		this.reindexedSpaces = reindexedSpaces;
	}

	@Override
	public void readFrom(StreamInput in) throws IOException {
		super.readFrom(in);
		spaceFound = in.readBoolean();
		reindexedSpaces = in.readOptionalString();
	}

	@Override
	public void writeTo(StreamOutput out) throws IOException {
		super.writeTo(out);
		out.writeBoolean(spaceFound);
		out.writeOptionalString(reindexedSpaces);
	}

}

==> elasticsearch-river-remote-1.6.3-sources.jar: org/jboss/elasticsearch/river/remote/mgm/fullupdate/NodeFullUpdateResponse.java <==
package org.jboss.elasticsearch.river.remote.mgm.fullupdate;

import java.io.IOException;

import org.elasticsearch.cluster.node.DiscoveryNode;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;
import org.jboss.elasticsearch.river.remote.mgm.NodeJRMgmBaseResponse;

/**
 * Full reindex node response.
 * 
 * @author Vlastimil Elias (velias at redhat dot com)
 */
public class NodeFullUpdateResponse extends NodeJRMgmBaseResponse {

	protected boolean spaceFound;

	protected String reindexedSpaces;

	protected NodeFullUpdateResponse() {
	}

	public NodeFullUpdateResponse(DiscoveryNode node) {
		super(node);
	}

	/**
	 * Create response with values to be send back to requestor.
	 * 
	 * @param node this response is for.
	 * @param riverFound set to true if you found river on this node
	 * @param spaceFound set to true if space reindex was requested and we found this space in given river
	 * @param reindexedSpaces CSV names of Spaces which was forced for full reindex
	 */
	public NodeFullUpdateResponse(DiscoveryNode node, boolean riverFound, boolean spaceFound, String reindexedSpaces) {
		super(node, riverFound);
		this.spaceFound = spaceFound;
		this.reindexedSpaces = reindexedSpaces;
	}

	@Override
	public void readFrom(StreamInput in) throws IOException {
		super.readFrom(in);
		spaceFound = in.readBoolean();
		reindexedSpaces = in.readOptionalString();
	}

	@Override
	public void writeTo(StreamOutput out) throws IOException {
		super.writeTo(out);
		out.writeBoolean(spaceFound);
		out.writeOptionalString(reindexedSpaces);
	}

	public boolean isSpaceFound() {
		return spaceFound;
	}

	public String getReindexedSpaces() {
		return reindexedSpaces;
	}

}
